summaryrefslogtreecommitdiffstats
path: root/runtime/src/window.rs
diff options
context:
space:
mode:
Diffstat (limited to 'runtime/src/window.rs')
-rw-r--r--runtime/src/window.rs8
1 files changed, 5 insertions, 3 deletions
diff --git a/runtime/src/window.rs b/runtime/src/window.rs
index 44b707b2..04bcfcd8 100644
--- a/runtime/src/window.rs
+++ b/runtime/src/window.rs
@@ -160,9 +160,11 @@ pub fn change_level<Message>(id: Id, level: Level) -> Command<Message> {
Command::single(command::Action::Window(Action::ChangeLevel(id, level)))
}
-/// Show window menu at cursor position.
-pub fn show_window_menu<Message>(id: Id) -> Command<Message> {
- Command::single(command::Action::Window(Action::ShowWindowMenu(id)))
+/// Show the [system menu] at cursor position.
+///
+/// [system menu]: https://en.wikipedia.org/wiki/Common_menus_in_Microsoft_Windows#System_menu
+pub fn show_system_menu<Message>(id: Id) -> Command<Message> {
+ Command::single(command::Action::Window(Action::ShowSystemMenu(id)))
}
/// Fetches an identifier unique to the window, provided by the underlying windowing system. This is